@@ -1,6 +1,6 @@
 import * as React from 'react';
 
-import { Widget } from '@phosphor/widgets';
+import { Widget } from '@lumino/widgets';
 import { ReactWidget } from '@jupyterlab/apputils';
 
 function MyComponent() {
